@@ -37,6 +37,7 @@ AlarmWindow::AlarmWindow(QWidget *parent) :
 
     m_timer = new QTimer(this);
     connect(m_timer, SIGNAL(timeout()), this, SLOT(fillAlarmList()));
+    showSettingsDialog();
 }
 
 AlarmWindow::~AlarmWindow()
@@ -205,8 +206,10 @@ void AlarmWindow::fillAlarmList()
                         ui->listWidget->addItem(item);
                     }
                 }
+                alarm_event_delete(aevent);
             }
     }
+
     free(list);
     if (!aFound) // now alarms
     {
