@@ -24,6 +24,7 @@ public slots:
 
 protected:
     void mouseReleaseEvent ( QMouseEvent * e );
+    void paintEvent(QPaintEvent *event);
 
 private:
     void loadSettings();
@@ -44,7 +45,7 @@ private:
 //    bool m_showStdOnly;
     int m_alarmFilter;
     int m_timeFrame;
-
+    float m_transparency;
     QTimer *m_timer;
 };
 
